@@ -2,9 +2,12 @@
 Init file for the SpatialCluster library.
 """
 
-version_info = (0, 0, 27)
+version_info = (0, 0, 31)
 __version__ = ".".join([str(x) for x in version_info])
 
 __all__ = [
+    "methods"
     "preprocess"
+    "visualization"
+    "utils"
 ]
\ No newline at end of file
